import { AnchorProvider, MethodsNamespace, Provider, Idl, AccountNamespace, Program } from '@project-serum/anchor';
import { ConfirmOptions, Connection, PublicKey, Signer, Transaction, TransactionInstruction } from '@solana/web3.js';
import { Wallet } from '../types';
export interface IProgramClient<IDL extends Idl = Idl> {
    program: Program<IDL>;
    get programId(): PublicKey;
    get provider(): Provider;
    get anchorProvider(): AnchorProvider;
    get connection(): Connection;
    get methods(): MethodsNamespace<IDL>;
    get accounts(): AccountNamespace<IDL>;
    get isWalletConnected(): boolean;
    get walletPubkey(): PublicKey;
}
export declare class ProgramClient<IDL extends Idl = Idl> implements IProgramClient<IDL> {
    readonly programId: PublicKey;
    program: Program<IDL>;
    constructor(idl: IDL, programId: PublicKey, rpcEndpoint: string, wallet?: Wallet, confirmOpts?: ConfirmOptions);
    connectWallet(idl: IDL, programId: PublicKey, wallet: Wallet, confirmOpts?: ConfirmOptions): void;
    get provider(): Provider;
    get anchorProvider(): AnchorProvider;
    get connection(): Connection;
    get methods(): MethodsNamespace<IDL>;
    get accounts(): AccountNamespace<IDL>;
    get isWalletConnected(): boolean;
    get walletPubkey(): PublicKey;
    addEventListener(eventName: string, callback: (event: any, slot: number) => void): number;
    removeEventListener(listener: number): Promise<void>;
    sendAndConfirm(tx: Transaction, signers?: Signer[], opts?: ConfirmOptions): Promise<string>;
    sendAndConfirmIxs(ixs: TransactionInstruction[], signers?: Signer[], opts?: ConfirmOptions): Promise<string>;
}
