"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProgramClient = void 0;
const anchor_1 = require("@project-serum/anchor");
const web3_js_1 = require("@solana/web3.js");
class ProgramClient {
    constructor(idl, programId, rpcEndpoint, wallet, confirmOpts = anchor_1.AnchorProvider.defaultOptions()) {
        this.programId = programId;
        const provider = {
            connection: new web3_js_1.Connection(rpcEndpoint, confirmOpts.commitment)
        };
        this.program = new anchor_1.Program(idl, programId, provider);
        if (wallet) {
            this.connectWallet(idl, programId, wallet, confirmOpts);
        }
    }
    connectWallet(idl, programId, wallet, confirmOpts = anchor_1.AnchorProvider.defaultOptions()) {
        const provider = new anchor_1.AnchorProvider(this.connection, wallet, confirmOpts);
        this.program = new anchor_1.Program(idl, programId, provider);
    }
    get provider() {
        return this.program.provider;
    }
    get anchorProvider() {
        const provider = this.program.provider;
        if (provider.wallet) {
            return provider;
        }
    }
    get connection() {
        return this.provider.connection;
    }
    get methods() {
        return this.program.methods;
    }
    get accounts() {
        return this.program.account;
    }
    get isWalletConnected() {
        return !!this.anchorProvider;
    }
    get walletPubkey() {
        return this.anchorProvider?.wallet.publicKey;
    }
    addEventListener(eventName, 
    // eslint-disable-next-line
    callback) {
        return this.program.addEventListener(eventName, callback);
    }
    async removeEventListener(listener) {
        return await this.program.removeEventListener(listener);
    }
    async sendAndConfirm(tx, signers, opts) {
        return this.anchorProvider?.sendAndConfirm(tx, signers, opts);
    }
    async sendAndConfirmIxs(ixs, signers, opts) {
        const tx = new web3_js_1.Transaction();
        tx.add(...ixs);
        return this.sendAndConfirm(tx, signers, opts);
    }
}
exports.ProgramClient = ProgramClient;
//# sourceMappingURL=client.js.map