"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeSettlePositionIx = exports.makeDepositDeliverableIx = exports.makeTransferBetweenSubAccountsIx = exports.makeUpdateAccountMarginIx = exports.makeEditSubAccountMarginIx = exports.makeConsumePerpEventsIx = exports.makeConsumeFuturesEventsIx = exports.makeUpdateFundingRateIx = exports.makeUpdateTokenIndexIx = exports.makeSettleSpotFundsIx = exports.makeCancelSpotOrderIx = exports.makeNewSpotOrderIx = exports.makeSettlePerpFundsIx = exports.makeCancelPerpOrdersIx = exports.makeCancelPerpOrderIx = exports.makeMultipleNewPerpOrdersIx = exports.makeNewPerpOrderIx = exports.makeSettleFuturesFundsIx = exports.makeCancelFuturesOrdersIx = exports.makeCancelFuturesOrderIx = exports.makeNewFuturesOrdersIx = exports.makeNewFuturesOrderIx = exports.makeWithdrawFundsIx = exports.makeDepositFundsIx = exports.makeSetSubAccountDelegateIx = exports.makeSetAccountDelegateIx = exports.makeCloseSpotOpenOrdersIx = exports.makeCacheOraclePricesIx = exports.makeInitSpotOpenOrdersIx = exports.makeCreateDerivativesOrdersAccountIx = exports.makeCreateOracleProductsIx = exports.makeCreatePoolIx = exports.makeCreatePerpMarketIx = exports.makeCreateFuturesMarketIx = exports.makeCreateSubAccountIx = exports.makeCreateWhitelistedAccountIx = exports.makeCreateAccountIx = exports.makeCreatePrivateClearingIx = exports.makeCreatePublicClearingIx = void 0;
const web3_js_1 = require("@solana/web3.js");
const spl_token_1 = require("@solana/spl-token");
const makeCreatePublicClearingIx = (client, clearing, authority, payer, args) => {
    return client.methods
        .createPublicClearing({ ...args, clearingType: args.clearingType })
        .accountsStrict({
        clearing,
        authority,
        payer,
        systemProgram: web3_js_1.SystemProgram.programId
    })
        .instruction();
};
exports.makeCreatePublicClearingIx = makeCreatePublicClearingIx;
const makeCreatePrivateClearingIx = (client, clearing, privateClearing, authority, payer, args) => {
    return client.methods
        .createPrivateClearing({
        ...args,
        clearingType: args.clearingType
    })
        .accountsStrict({
        clearing,
        privateClearing,
        authority,
        payer,
        systemProgram: web3_js_1.SystemProgram.programId
    })
        .instruction();
};
exports.makeCreatePrivateClearingIx = makeCreatePrivateClearingIx;
const makeCreateAccountIx = (client, clearing, account, authority, payer, accountNumber, accountBump) => {
    return client.methods
        .createAccount(accountNumber, accountBump)
        .accountsStrict({
        clearing,
        masterAccount: account,
        authority,
        payer,
        systemProgram: web3_js_1.SystemProgram.programId
    })
        .instruction();
};
exports.makeCreateAccountIx = makeCreateAccountIx;
const makeCreateWhitelistedAccountIx = (client, clearing, whitelist, account, authority, payer, accountNumber, accountBump) => {
    return client.methods
        .createWhitelistedAccount(accountNumber, accountBump)
        .accountsStrict({
        clearing,
        whitelist,
        masterAccount: account,
        authority,
        payer,
        systemProgram: web3_js_1.SystemProgram.programId
    })
        .instruction();
};
exports.makeCreateWhitelistedAccountIx = makeCreateWhitelistedAccountIx;
const makeCreateSubAccountIx = (client, masterAccount, subAccount, authority, payer, subAccountNumber, subAccountBump, subAccountAlias) => {
    return client.methods
        .createSubAccount(subAccountNumber, subAccountBump, subAccountAlias)
        .accountsStrict({
        masterAccount,
        subAccount,
        authority,
        payer,
        systemProgram: web3_js_1.SystemProgram.programId
    });
};
exports.makeCreateSubAccountIx = makeCreateSubAccountIx;
const makeCreateFuturesMarketIx = (client, clearing, cacheAccount, market, priceHistory, oracleProducts, quotePool, orderbook, bids, asks, eventQueue, authority, payer, args) => {
    return client.methods
        .createFuturesMarket({
        ...args,
        marketType: args.marketType,
        deliveryType: args.deliveryType
    })
        .accountsStrict({
        cacheAccount,
        clearing,
        market,
        priceHistory,
        oracleProducts,
        quotePool,
        orderbook,
        bids,
        asks,
        eventQueue,
        authority,
        payer,
        systemProgram: web3_js_1.SystemProgram.programId,
        rent: web3_js_1.SYSVAR_RENT_PUBKEY
    })
        .instruction();
};
exports.makeCreateFuturesMarketIx = makeCreateFuturesMarketIx;
const makeCreatePerpMarketIx = (client, clearing, cacheAccount, market, oracleProducts, quotePool, orderbook, bids, asks, eventQueue, authority, payer, args) => {
    return client.methods
        .createPerpMarket({
        ...args,
        marketType: args.marketType
    })
        .accountsStrict({
        clearing,
        cacheAccount,
        market,
        oracleProducts,
        quotePool,
        orderbook,
        bids,
        asks,
        eventQueue,
        authority,
        payer,
        systemProgram: web3_js_1.SystemProgram.programId,
        rent: web3_js_1.SYSVAR_RENT_PUBKEY
    })
        .instruction();
};
exports.makeCreatePerpMarketIx = makeCreatePerpMarketIx;
const makeCreatePoolIx = (client, clearing, cacheAccount, pool, poolNode, tokenMint, tokenVault, vaultSigner, oracleProducts, dexMarket, authority, payer, args) => {
    return client.methods
        .createPool({ ...args })
        .accountsStrict({
        clearing,
        cacheAccount,
        pool,
        poolNode,
        tokenMint,
        tokenVault,
        vaultSigner,
        oracleProducts,
        dexMarket,
        authority,
        payer,
        systemProgram: web3_js_1.SystemProgram.programId,
        tokenProgram: spl_token_1.TOKEN_PROGRAM_ID,
        rent: web3_js_1.SYSVAR_RENT_PUBKEY
    })
        .instruction();
};
exports.makeCreatePoolIx = makeCreatePoolIx;
const makeCreateOracleProductsIx = (client, cacheAccount, oracleProducts, authority, payer, productsArr, args) => {
    return client.methods
        .createOracleProducts({
        ...args,
        productsType: args.productsType
    })
        .accountsStrict({
        cacheAccount,
        oracleProducts,
        authority,
        payer,
        systemProgram: web3_js_1.SystemProgram.programId
    })
        .remainingAccounts(productsArr.map((product) => ({
        pubkey: product,
        isSigner: false,
        isWritable: false
    })))
        .instruction();
};
exports.makeCreateOracleProductsIx = makeCreateOracleProductsIx;
const makeCreateDerivativesOrdersAccountIx = (client, masterAccount, market, openOrders, authority, payer) => {
    return client.methods
        .createOrdersAccount()
        .accountsStrict({
        masterAccount,
        market,
        openOrders,
        authority,
        payer,
        systemProgram: web3_js_1.SystemProgram.programId,
        rent: web3_js_1.SYSVAR_RENT_PUBKEY
    })
        .instruction();
};
exports.makeCreateDerivativesOrdersAccountIx = makeCreateDerivativesOrdersAccountIx;
const makeInitSpotOpenOrdersIx = (client, masterAccount, subAccount, pool, tokenMint, dexMarket, openOrders, authority, payer) => {
    return client.methods
        .initSpotOpenOrders()
        .accountsStrict({
        masterAccount,
        subAccount,
        pool,
        tokenMint,
        dexMarket,
        openOrders,
        authority,
        payer,
        systemProgram: web3_js_1.SystemProgram.programId,
        dexProgram: client.dexPID,
        rent: web3_js_1.SYSVAR_RENT_PUBKEY
    })
        .instruction();
};
exports.makeInitSpotOpenOrdersIx = makeInitSpotOpenOrdersIx;
const makeCacheOraclePricesIx = (client, cacheAccount, oracleProducts, productsArr, cacheIndex, pool, futuresMarket) => {
    const remainingAccounts = [];
    for (const product in productsArr) {
        remainingAccounts.push({
            pubkey: product,
            isSigner: false,
            isWritable: false
        });
    }
    if (pool) {
        remainingAccounts.push({
            pubkey: pool,
            isSigner: false,
            isWritable: false
        });
    }
    if (futuresMarket) {
        remainingAccounts.push({
            pubkey: futuresMarket,
            isSigner: false,
            isWritable: false
        });
    }
    return client.methods
        .cacheOraclePrices(cacheIndex)
        .accountsStrict({
        cacheAccount,
        oracleProducts
    })
        .remainingAccounts(remainingAccounts)
        .instruction();
};
exports.makeCacheOraclePricesIx = makeCacheOraclePricesIx;
const makeCloseSpotOpenOrdersIx = (client, masterAccount, subAccount, assetPool, tokenMint, dexMarket, openOrders, authority) => {
    return client.methods
        .closeSpotOpenOrders()
        .accountsStrict({
        masterAccount,
        subAccount,
        assetPool,
        tokenMint,
        dexMarket,
        openOrders,
        authority,
        dexProgram: client.dexPID
    })
        .instruction();
};
exports.makeCloseSpotOpenOrdersIx = makeCloseSpotOpenOrdersIx;
const makeSetAccountDelegateIx = (client, masterAccount, delegate, authority) => {
    return client.methods
        .setAccountDelegate()
        .accountsStrict({
        masterAccount,
        authority,
        delegate
    })
        .instruction();
};
exports.makeSetAccountDelegateIx = makeSetAccountDelegateIx;
const makeSetSubAccountDelegateIx = (client, subAccount, delegate, authority) => {
    return client.methods
        .setSubAccountDelegate()
        .accountsStrict({
        subAccount,
        authority,
        delegate
    })
        .instruction();
};
exports.makeSetSubAccountDelegateIx = makeSetSubAccountDelegateIx;
const makeDepositFundsIx = (client, clearing, cacheAccount, masterAccount, subAccount, pool, poolNode, sourceTokenAccount, tokenVault, tokenMint, authority, amount) => {
    return client.methods
        .depositFunds(amount)
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        pool,
        poolNode,
        sourceTokenAccount,
        tokenVault,
        tokenMint,
        authority,
        tokenProgram: spl_token_1.TOKEN_PROGRAM_ID
    })
        .instruction();
};
exports.makeDepositFundsIx = makeDepositFundsIx;
const makeWithdrawFundsIx = (client, clearing, cacheAccount, masterAccount, subAccount, pool, poolNode, tokenVault, vaultSigner, destinationTokenAccount, tokenMint, authority, amount, zero = false) => {
    return client.methods
        .withdrawFunds(amount, zero)
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        pool,
        poolNode,
        tokenVault,
        vaultSigner,
        destinationTokenAccount,
        tokenMint,
        authority,
        tokenProgram: spl_token_1.TOKEN_PROGRAM_ID
    })
        .instruction();
};
exports.makeWithdrawFundsIx = makeWithdrawFundsIx;
const makeNewFuturesOrderIx = (client, clearing, cacheAccount, masterAccount, subAccount, market, openOrders, priceHistory, orderbook, eventQueue, bids, asks, quotePoolNode, authority, args) => {
    return client.methods
        .newFuturesOrder({
        ...args,
        side: args.side,
        orderType: args.orderType
    })
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        market,
        openOrders,
        priceHistory,
        orderbook,
        eventQueue,
        bids,
        asks,
        quotePoolNode,
        authority
    })
        .instruction();
};
exports.makeNewFuturesOrderIx = makeNewFuturesOrderIx;
const makeNewFuturesOrdersIx = (client, clearing, cacheAccount, masterAccount, subAccount, market, openOrders, priceHistory, orderbook, eventQueue, bids, asks, quotePoolNode, authority, args) => {
    return client.methods
        .multipleNewFuturesOrders({
        ...args
    })
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        market,
        openOrders,
        priceHistory,
        orderbook,
        eventQueue,
        bids,
        asks,
        quotePoolNode,
        authority
    })
        .instruction();
};
exports.makeNewFuturesOrdersIx = makeNewFuturesOrdersIx;
const makeCancelFuturesOrderIx = (client, clearing, cacheAccount, masterAccount, subAccount, market, openOrders, orderbook, eventQueue, bids, asks, quotePoolNode, authority, args) => {
    return client.methods
        .cancelFuturesOrder({
        ...args,
        side: args.side
    })
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        market,
        openOrders,
        orderbook,
        eventQueue,
        bids,
        asks,
        quotePoolNode,
        authority
    })
        .instruction();
};
exports.makeCancelFuturesOrderIx = makeCancelFuturesOrderIx;
const makeCancelFuturesOrdersIx = (client, clearing, cacheAccount, masterAccount, subAccount, market, openOrders, orderbook, eventQueue, bids, asks, quotePoolNode, authority, args) => {
    return client.methods
        .cancelFuturesOrders({
        ...args
    })
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        market,
        openOrders,
        orderbook,
        eventQueue,
        bids,
        asks,
        quotePoolNode,
        authority
    })
        .instruction();
};
exports.makeCancelFuturesOrdersIx = makeCancelFuturesOrdersIx;
const makeSettleFuturesFundsIx = (client, cacheAccount, clearing, masterAccount, subAccount, openOrders, market, quotePoolNode, authority) => {
    return client.methods
        .settleFuturesFunds()
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        openOrders,
        market,
        quotePoolNode,
        authority
    })
        .instruction();
};
exports.makeSettleFuturesFundsIx = makeSettleFuturesFundsIx;
const makeNewPerpOrderIx = (client, clearing, cacheAccount, masterAccount, subAccount, market, openOrders, orderbook, eventQueue, bids, asks, quotePoolNode, authority, args) => {
    return client.methods
        .newPerpOrder({
        ...args,
        side: args.side,
        orderType: args.orderType
    })
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        market,
        openOrders,
        orderbook,
        eventQueue,
        bids,
        asks,
        quotePoolNode,
        authority
    })
        .instruction();
};
exports.makeNewPerpOrderIx = makeNewPerpOrderIx;
const makeMultipleNewPerpOrdersIx = (client, clearing, cacheAccount, masterAccount, subAccount, market, openOrders, orderbook, eventQueue, bids, asks, quotePoolNode, authority, args) => {
    return client.methods
        .multipleNewPerpOrders({
        ...args
    })
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        market,
        openOrders,
        orderbook,
        eventQueue,
        bids,
        asks,
        quotePoolNode,
        authority
    })
        .instruction();
};
exports.makeMultipleNewPerpOrdersIx = makeMultipleNewPerpOrdersIx;
const makeCancelPerpOrderIx = (client, clearing, cacheAccount, masterAccount, subAccount, market, openOrders, orderbook, eventQueue, bids, asks, quotePoolNode, authority, args) => {
    return client.methods
        .cancelPerpOrder({
        ...args,
        side: args.side
    })
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        market,
        openOrders,
        orderbook,
        eventQueue,
        bids,
        asks,
        quotePoolNode,
        authority
    })
        .instruction();
};
exports.makeCancelPerpOrderIx = makeCancelPerpOrderIx;
const makeCancelPerpOrdersIx = (client, clearing, cacheAccount, masterAccount, subAccount, market, openOrders, orderbook, eventQueue, bids, asks, quotePoolNode, authority, args) => {
    return client.methods
        .cancelPerpOrders({
        ...args
    })
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        market,
        openOrders,
        orderbook,
        eventQueue,
        bids,
        asks,
        quotePoolNode,
        authority
    })
        .instruction();
};
exports.makeCancelPerpOrdersIx = makeCancelPerpOrdersIx;
const makeSettlePerpFundsIx = (client, clearing, cacheAccount, masterAccount, subAccount, openOrders, market, quotePoolNode) => {
    return client.methods
        .settlePerpFunds()
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        openOrders,
        market,
        quotePoolNode
    })
        .instruction();
};
exports.makeSettlePerpFundsIx = makeSettlePerpFundsIx;
const makeNewSpotOrderIx = (client, clearing, cacheAccount, masterAccount, subAccount, assetPoolNode, quotePoolNode, assetMint, assetVault, vaultSigner, quoteVault, authority, dexAccounts, args) => {
    return client.methods
        .newSpotOrder({
        ...args,
        side: args.side,
        orderType: args.orderType,
        selfTradeBehavior: args.selfTradeBehavior
    })
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        assetPoolNode,
        quotePoolNode,
        assetMint,
        assetVault,
        quoteVault,
        vaultSigner,
        authority,
        dex: {
            ...dexAccounts,
            rent: web3_js_1.SYSVAR_RENT_PUBKEY,
            tokenProgram: spl_token_1.TOKEN_PROGRAM_ID,
            dexProgram: client.dexPID
        }
    })
        .instruction();
};
exports.makeNewSpotOrderIx = makeNewSpotOrderIx;
const makeCancelSpotOrderIx = (client, clearing, cacheAccount, masterAccount, subAccount, assetPoolNode, quotePoolNode, assetMint, assetVault, quoteVault, authority, dexAccounts, args) => {
    return client.methods
        .cancelSpotOrder({
        ...args,
        side: args.side
    })
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        assetPoolNode,
        quotePoolNode,
        assetMint,
        assetVault,
        quoteVault,
        authority,
        dex: {
            ...dexAccounts,
            tokenProgram: spl_token_1.TOKEN_PROGRAM_ID,
            dexProgram: client.dexPID
        }
    })
        .instruction();
};
exports.makeCancelSpotOrderIx = makeCancelSpotOrderIx;
const makeSettleSpotFundsIx = (client, clearing, cacheAccount, masterAccount, subAccount, assetPoolNode, quotePoolNode, assetMint, assetVault, quoteVault, authority, dexAccounts) => {
    return client.methods.settleSpotFunds().accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        subAccount,
        assetPoolNode,
        quotePoolNode,
        assetMint,
        assetVault,
        quoteVault,
        authority,
        dex: {
            ...dexAccounts,
            tokenProgram: spl_token_1.TOKEN_PROGRAM_ID,
            dexProgram: client.dexPID
        }
    });
};
exports.makeSettleSpotFundsIx = makeSettleSpotFundsIx;
const makeUpdateTokenIndexIx = (client, cacheAccount, pool, poolNodes) => {
    return client.methods
        .updateTokenIndex()
        .accountsStrict({ cacheAccount, pool })
        .remainingAccounts(poolNodes.map((p) => ({
        pubkey: p,
        isSigner: false,
        isWritable: false
    })))
        .instruction();
};
exports.makeUpdateTokenIndexIx = makeUpdateTokenIndexIx;
const makeUpdateFundingRateIx = (client, cacheAccount, market, orderbook, bids, asks) => {
    return client.methods
        .updateFundingRate()
        .accountsStrict({
        cacheAccount,
        market,
        orderbook,
        bids,
        asks
    })
        .instruction();
};
exports.makeUpdateFundingRateIx = makeUpdateFundingRateIx;
const makeConsumeFuturesEventsIx = (client, clearing, market, orderbook, eventQueue, openOrders, limit) => {
    return client.methods
        .consumeFuturesEvents(limit)
        .accountsStrict({
        clearing,
        market,
        orderbook,
        eventQueue
    })
        .remainingAccounts(openOrders.map((addr) => ({
        pubkey: addr,
        isSigner: false,
        isWritable: true
    })))
        .instruction();
};
exports.makeConsumeFuturesEventsIx = makeConsumeFuturesEventsIx;
const makeConsumePerpEventsIx = (client, clearing, market, orderbook, eventQueue, openOrders, limit) => {
    return client.methods
        .consumePerpEvents(limit)
        .accountsStrict({
        clearing,
        market,
        orderbook,
        eventQueue
    })
        .remainingAccounts(openOrders.map((addr) => ({
        pubkey: addr,
        isSigner: false,
        isWritable: true
    })))
        .instruction();
};
exports.makeConsumePerpEventsIx = makeConsumePerpEventsIx;
const makeEditSubAccountMarginIx = (client, masterAccount, subAccount, authority, marginingType) => {
    return client.methods
        .editSubAccountMargining(marginingType)
        .accountsStrict({
        masterAccount,
        subAccount,
        authority
    })
        .instruction();
};
exports.makeEditSubAccountMarginIx = makeEditSubAccountMarginIx;
const makeUpdateAccountMarginIx = (client, cacheAccount, masterAccount, signer, subAccounts) => {
    return client.methods
        .updateAccountMargin()
        .accountsStrict({
        cacheAccount,
        masterAccount,
        signer
    })
        .remainingAccounts(subAccounts.map((addr) => ({
        pubkey: addr,
        isSigner: false,
        isWritable: false
    })))
        .instruction();
};
exports.makeUpdateAccountMarginIx = makeUpdateAccountMarginIx;
const makeTransferBetweenSubAccountsIx = (client, clearing, cacheAccount, masterAccount, fromSubAccount, toSubAccount, assetMint, assetPoolNode, authority, amount) => {
    return client.methods
        .transferBetweenSubAccounts(amount)
        .accountsStrict({
        clearing,
        cacheAccount,
        masterAccount,
        fromSubAccount,
        toSubAccount,
        assetMint,
        assetPoolNode,
        authority
    })
        .instruction();
};
exports.makeTransferBetweenSubAccountsIx = makeTransferBetweenSubAccountsIx;
const makeDepositDeliverableIx = (client, market, pool, poolNode, tokenMint, tokenVault, sourceTokenAccount, authority, amount) => {
    return client.methods
        .depositDeliverable(amount)
        .accountsStrict({
        market,
        pool,
        poolNode,
        tokenMint,
        tokenVault,
        sourceTokenAccount,
        authority,
        tokenProgram: spl_token_1.TOKEN_PROGRAM_ID
    })
        .instruction();
};
exports.makeDepositDeliverableIx = makeDepositDeliverableIx;
const makeSettlePositionIx = (client, cacheAccount, masterAccount, subAccount, market, quotePoolNode) => {
    return client.methods
        .settlePosition()
        .accountsStrict({
        cacheAccount,
        masterAccount,
        subAccount,
        market,
        quotePoolNode
    })
        .instruction();
};
exports.makeSettlePositionIx = makeSettlePositionIx;
//# sourceMappingURL=cypher.js.map