"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeEndDepositIx = exports.makeCreateDepositIx = void 0;
const web3_js_1 = require("@solana/web3.js");
const shared_1 = require("../constants/shared");
const pda_1 = require("../utils/pda");
const spl_token_1 = require("@solana/spl-token");
const makeCreateDepositIx = async (client, campaign, poolAddress, poolNodeAddress, poolNodeVaultAddress, assetMint, rewardMint, amount) => {
    const deposit = new web3_js_1.Keypair();
    const tempTokenAccount = new web3_js_1.Keypair();
    const [depositAuthority] = (0, pda_1.deriveDepositAuthority)(deposit.publicKey, client.programId);
    const [clearing] = (0, pda_1.derivePublicClearingAddress)(client.cypherProgramId);
    const [cypherAccount, accountBump] = (0, pda_1.deriveAccountAddress)(depositAuthority, 0, client.cypherProgramId);
    const [cypherSubAccount, subAccountBump] = (0, pda_1.deriveSubAccountAddress)(cypherAccount, 0, client.cypherProgramId);
    const fundingAccount = await (0, spl_token_1.getAssociatedTokenAddress)(client.walletPubkey, assetMint);
    return {
        signers: [deposit, tempTokenAccount],
        ixs: [
            await client.methods
                .createDeposit(accountBump, subAccountBump, amount)
                .accountsStrict({
                campaign: campaign,
                deposit: deposit.publicKey,
                cacheAccount: shared_1.CONFIGS[client.cluster].CACHE,
                clearing,
                cypherAccount,
                cypherSubAccount,
                depositAuthority,
                fundingAccount,
                tempTokenAccount: tempTokenAccount.publicKey,
                assetMint: assetMint,
                pool: poolAddress,
                poolNode: poolNodeAddress,
                poolNodeVault: poolNodeVaultAddress,
                payer: client.walletPubkey,
                signer: client.walletPubkey,
                cypherProgram: client.cypherProgramId,
                tokenProgram: spl_token_1.TOKEN_PROGRAM_ID,
                rent: web3_js_1.SYSVAR_RENT_PUBKEY,
                systemProgram: web3_js_1.SystemProgram.programId
            })
                .instruction()
        ]
    };
};
exports.makeCreateDepositIx = makeCreateDepositIx;
const makeEndDepositIx = async (client, campaign, campaignRewardVault, campaignRewardVaultAuthority, deposit, pool, poolNode, poolNodeVault, poolNodeVaultSigner, assetMint, rewardMint) => {
    const tempTokenAccount = new web3_js_1.Keypair();
    const [depositAuthority] = (0, pda_1.deriveDepositAuthority)(deposit, client.programId);
    const [clearing] = (0, pda_1.derivePublicClearingAddress)(client.cypherProgramId);
    const [cypherAccount] = (0, pda_1.deriveAccountAddress)(depositAuthority, 0, client.cypherProgramId);
    const [cypherSubAccount] = (0, pda_1.deriveSubAccountAddress)(cypherAccount, 0, client.cypherProgramId);
    const assetTokenAccount = await (0, spl_token_1.getAssociatedTokenAddress)(client.walletPubkey, assetMint);
    const rewardTokenAccount = await (0, spl_token_1.getAssociatedTokenAddress)(client.walletPubkey, rewardMint);
    return {
        signers: [tempTokenAccount],
        ixs: [
            await client.methods
                .endDeposit()
                .accountsStrict({
                campaign: campaign,
                campaignRewardVault,
                campaignRewardVaultAuthority,
                deposit,
                cacheAccount: shared_1.CONFIGS[client.cluster].CACHE,
                clearing,
                cypherAccount,
                cypherSubAccount,
                depositAuthority,
                tempTokenAccount: tempTokenAccount.publicKey,
                assetTokenAccount,
                assetMint: assetMint,
                pool,
                poolNode,
                poolNodeVault,
                poolNodeVaultSigner,
                rewardTokenAccount,
                rewardMint,
                payer: client.walletPubkey,
                signer: client.walletPubkey,
                cypherProgram: client.cypherProgramId,
                tokenProgram: spl_token_1.TOKEN_PROGRAM_ID,
                associatedTokenProgram: spl_token_1.ASSOCIATED_TOKEN_PROGRAM_ID,
                rent: web3_js_1.SYSVAR_RENT_PUBKEY,
                systemProgram: web3_js_1.SystemProgram.programId
            })
                .instruction()
        ]
    };
};
exports.makeEndDepositIx = makeEndDepositIx;
//# sourceMappingURL=liquidityIncentiveProgram.js.map